@@ -20,10 +20,12 @@ from .data_types import (
     ColorScheme,
     CookieSameSite,
     CookieType,
+    DownloadedFile,
     ElementState,
     GeoLocation,
     HttpCredentials,
     Proxy,
+    RecordVideo,
     RequestMethod,
     SelectAttribute,
     SelectionType,
